using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace OPCSystemsQuickStartWPF40CS1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private bool m_LoggedIn = false;
        internal OPCWPFDashboard.OPCWPFLogIn m_OPCWPFLogin = new OPCWPFDashboard.OPCWPFLogIn();

        private string CurrentTrend;
        private void mnuLogOn_Click(System.Object sender, System.Windows.RoutedEventArgs e)
        {
            if (m_LoggedIn)
            {
                m_OPCWPFLogin.LogOff();

                string ErrorString = "";
                m_LoggedIn = false;
                mnuLogOn.Header = "Log In";
                mnuCurrentUser.Header = "Current User: Nobody";
                this.OPCTrend.LogOff();
                this.OPCAlarm.LogOff();
            }
            else
            {
                string resultString = null;
                LogIn dlg = new LogIn();
                dlg.Owner = this;

                dlg.ShowDialog();
                if (dlg.DialogResult.Equals(System.Windows.Forms.DialogResult.OK))
                {
                    if (string.IsNullOrEmpty(dlg.TextBoxUserName.Text))
                    {
                        MessageBox.Show("User Name is blank", "Invalid User Name", MessageBoxButton.OK, MessageBoxImage.Error);
                        return;
                    }
                    resultString = m_OPCWPFLogin.LogIn(dlg.TextBoxUserName.Text, dlg.PasswordBoxPassword.Password);
                    if (resultString != "Success")
                    {
                        MessageBox.Show(resultString, "Log In " + dlg.TextBoxUserName.Text, MessageBoxButton.OK, MessageBoxImage.Error);
                        return;
                    }

                    m_LoggedIn = true;
                    mnuLogOn.Header = "Log Off";
                    mnuCurrentUser.Header = "Current User: " + dlg.TextBoxUserName.Text;
                    this.OPCTrend.Login(dlg.TextBoxUserName.Text, dlg.PasswordBoxPassword.Password);
                    this.OPCAlarm.Login(dlg.TextBoxUserName.Text, dlg.PasswordBoxPassword.Password);

                }
            }
        }

        private void mnuOpenOn_Click(System.Object sender, System.Windows.RoutedEventArgs e)
        {
            // Displays an OpenFileDialog so the user can select a Trend Setup.
            Microsoft.Win32.OpenFileDialog openFileDialog1 = new Microsoft.Win32.OpenFileDialog();
            openFileDialog1.Filter = "Trend Files|*.Chart";
            openFileDialog1.Title = "Select a Trend File";

            // Show the Dialog.
            // If the user clicked OK in the dialog and 
            // a .CHART file was selected, open it
            if (openFileDialog1.ShowDialog() == true)
            {
                this.OPCTrend.StopTrendRuntime();
                this.OPCTrend.ConfigurationFile = openFileDialog1.FileName;
                Properties.Settings.Default.TrendFileName = this.OPCTrend.ConfigurationFile;
                this.OPCTrend.LoadConfiguration();
                this.OPCTrend.StartTrendRuntime();
                CurrentTrend = openFileDialog1.FileName;
                Properties.Settings.Default.TrendFileName = CurrentTrend;
                this.OPCTrend.ConfigurationFile = "";
                Properties.Settings.Default.Save();

            }
        }

        private void mnuSaveOn_Click(System.Object sender, System.Windows.RoutedEventArgs e)
        {

            if (!string.IsNullOrEmpty(CurrentTrend))
            {
                Properties.Settings.Default.TrendFileName = CurrentTrend;
                OPCTrend.ConfigurationFile = CurrentTrend;
                OPCTrend.SaveConfiguration();
            }
            else
            {
                //Displays a SaveFileDialog so the user can save the Trend 
                Microsoft.Win32.SaveFileDialog saveFileDialog1 = new Microsoft.Win32.SaveFileDialog();
                saveFileDialog1.Filter = "Trend Configuration|*.Chart";
                saveFileDialog1.Title = "Save a Trend Configuration";
                saveFileDialog1.ShowDialog();

                // If the file name is not an empty string open it for saving.

                if (!string.IsNullOrEmpty(saveFileDialog1.FileName))
                {
                    Properties.Settings.Default.TrendFileName = saveFileDialog1.FileName;
                    OPCTrend.ConfigurationFile = saveFileDialog1.FileName;
                    MessageBox.Show(this.OPCTrend.ConfigurationFile);
                    OPCTrend.SaveConfiguration();
                }
            }
        }

        private void mnuSaveAsOn_Click(System.Object sender, System.Windows.RoutedEventArgs e)
        {
            //Displays a SaveFileDialog so the user can save the Trend 
            Microsoft.Win32.SaveFileDialog saveFileDialog1 = new Microsoft.Win32.SaveFileDialog();
            saveFileDialog1.Filter = "Trend Configuration|*.Chart";
            saveFileDialog1.Title = "Save a Trend Configuration";
            saveFileDialog1.ShowDialog();

            // If the file name is not an empty string open it for saving.

            if (!string.IsNullOrEmpty(saveFileDialog1.FileName))
            {
                Properties.Settings.Default.TrendFileName = saveFileDialog1.FileName;
                Properties.Settings.Default.Save();
                CurrentTrend = saveFileDialog1.FileName;
                OPCTrend.ConfigurationFile = saveFileDialog1.FileName;
                OPCTrend.SaveConfiguration();
                this.OPCTrend.ConfigurationFile = "";
            }
        }

    }
}
